package com.hungraim.ltc.controller;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.pojo.entity.SysConfig.ChCfgSrvOrganType;
import com.hungraim.ltc.pojo.entity.SysConfig.ChFndSrvOrganLevel;
import com.hungraim.ltc.pojo.vo.disable.SrvOrganListVo;
import com.hungraim.ltc.pojo.vo.system.SrvOrganVo;
import com.hungraim.ltc.service.SrvOrganService;
import com.hungraim.ltc.util.Result;
import com.hungraim.ltc.util.ResultCode;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/api.apply/srvOrgan")
@AllArgsConstructor
public class SrvOrganController {

    private final SrvOrganService srvOrganService;

    /**
     * 分页查询护理机构列表
     *
     * @param pageNum        分页参数
     * @param pageSize       分页参数
     * @param organId        适用机构id
     * @param isInvolveChild 是否包含下层机构
     * @param creditCode     统一社会信用代码
     * @param srvOrganName   护理机构名称
     * @return 返回护理机构列表
     */
    @GetMapping("/list")
    public Result<Page<SrvOrganListVo>> getSrvOrganList(Integer pageNum, Integer pageSize, Long organId, Boolean isInvolveChild, String creditCode, String srvOrganName) {
        Page<SrvOrganListVo> page = new Page<>(pageNum, pageSize);
        page = srvOrganService.getSrvOrganList(page, organId, isInvolveChild, creditCode, srvOrganName);
        return Result.success(page);
    }

    /**
     * 获取所有服务机构等级
     *
     * @return 返回服务机构等级
     */
    @GetMapping("/srvOrganLevels")
    public Result<List<ChFndSrvOrganLevel>> getSrvOrganLevels() {
        List<ChFndSrvOrganLevel> srvOrganLevels = srvOrganService.getSrvOrganLevels();
        return Result.success(srvOrganLevels);
    }

    /**
     * 获取所有服务机构类型
     *
     * @return 返回所有服务机构类型
     */
    @GetMapping("/srvOrganTypes")
    public Result<List<ChCfgSrvOrganType>> getSrvOrganTypes() {
        List<ChCfgSrvOrganType> chCfgSrvOrganTypes = srvOrganService.getSrvOrganTypes();
        return Result.success(chCfgSrvOrganTypes);
    }


    /**
     * 添加护理机构
     *
     * @param srvOrganVo 护理机构包装对象
     * @return 返回操作结果
     */
    @PostMapping("/srvOrgan")
    public Result saveSrvOrgan(SrvOrganVo srvOrganVo) {
        if (StrUtil.isBlank(srvOrganVo.getOrganId()) || StrUtil.isBlank(srvOrganVo.getDistrictProvincial()) || StrUtil.isBlank(srvOrganVo.getDistrictCity()) || StrUtil.isBlank(srvOrganVo.getDistrictArea()) || StrUtil.isBlank(srvOrganVo.getAcptProvincial()) || StrUtil.isBlank(srvOrganVo.getAcptCity()) || StrUtil.isBlank(srvOrganVo.getAcptArea()) || StrUtil.isBlank(srvOrganVo.getAcptStreet()) || StrUtil.isBlank(srvOrganVo.getAcptStreet()) || StrUtil.isBlank(srvOrganVo.getBankDistrictProvincial()) || StrUtil.isBlank(srvOrganVo.getBankDistrictCity()) || StrUtil.isBlank(srvOrganVo.getSrvOrganName()) || StrUtil.isBlank(srvOrganVo.getPermitId()) || null == srvOrganVo.getOrganTypeId() || null == srvOrganVo.getLevelCode() || StrUtil.isBlank(srvOrganVo.getLinkName()) || StrUtil.isBlank(srvOrganVo.getLinkTel()) || StrUtil.isBlank(srvOrganVo.getSrvType()) || null == srvOrganVo.getBunk() || StrUtil.isBlank(srvOrganVo.getUnifiedSocialCreditCode()) || StrUtil.isBlank(srvOrganVo.getSrvType()) || StrUtil.isBlank(srvOrganVo.getAccName()) || StrUtil.isBlank(srvOrganVo.getBankAccCode()) || StrUtil.isBlank(srvOrganVo.getBankAccName()) || StrUtil.isBlank(srvOrganVo.getBankNo()) || StrUtil.isBlank(srvOrganVo.getBankDistrictWebsite()) || null == srvOrganVo.getCardType() || null == srvOrganVo.getFileDataList() || srvOrganVo.getFileDataList().size() < 3) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        // 参数校验通过，调用service添加护理机构
        srvOrganService.saveOrUpdateSrvOrgan(srvOrganVo);
        return Result.success();
    }

    /**
     * 修改护理机构
     *
     * @param srvOrganVo 护理机构包装对象
     * @return 返回操作结果
     */
    @PutMapping("/srvOrgan")
    public Result updateSrvOrgan(SrvOrganVo srvOrganVo) {
        if (null == srvOrganVo.getSrvOrganId() || StrUtil.isBlank(srvOrganVo.getOrganId()) || StrUtil.isBlank(srvOrganVo.getDistrictProvincial()) || StrUtil.isBlank(srvOrganVo.getDistrictCity()) || StrUtil.isBlank(srvOrganVo.getDistrictArea()) || StrUtil.isBlank(srvOrganVo.getAcptProvincial()) || StrUtil.isBlank(srvOrganVo.getAcptCity()) || StrUtil.isBlank(srvOrganVo.getAcptArea()) || StrUtil.isBlank(srvOrganVo.getAcptStreet()) || StrUtil.isBlank(srvOrganVo.getAcptStreet()) || StrUtil.isBlank(srvOrganVo.getBankDistrictProvincial()) || StrUtil.isBlank(srvOrganVo.getBankDistrictCity()) || StrUtil.isBlank(srvOrganVo.getSrvOrganName()) || StrUtil.isBlank(srvOrganVo.getPermitId()) || null == srvOrganVo.getOrganTypeId() || null == srvOrganVo.getLevelCode() || StrUtil.isBlank(srvOrganVo.getLinkName()) || StrUtil.isBlank(srvOrganVo.getLinkTel()) || StrUtil.isBlank(srvOrganVo.getSrvType()) || null == srvOrganVo.getBunk() || StrUtil.isBlank(srvOrganVo.getUnifiedSocialCreditCode()) || StrUtil.isBlank(srvOrganVo.getSrvType()) || StrUtil.isBlank(srvOrganVo.getAccName()) || StrUtil.isBlank(srvOrganVo.getBankAccCode()) || StrUtil.isBlank(srvOrganVo.getBankAccName()) || StrUtil.isBlank(srvOrganVo.getBankNo()) || StrUtil.isBlank(srvOrganVo.getBankDistrictWebsite()) || null == srvOrganVo.getCardType() || null == srvOrganVo.getFileDataList() || srvOrganVo.getFileDataList().size() < 3) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        // 参数校验通过，调用service修改护理机构
        srvOrganService.saveOrUpdateSrvOrgan(srvOrganVo);
        return Result.success();
    }

    /**
     * 查询护理机构详情
     *
     * @param srvOrganId 护理机构id
     * @return 返回护理机构详情
     */
    @GetMapping("/srvOrgan")
    public Result<SrvOrganVo> getSrvOrganDetail(Long srvOrganId) {
        if (null == srvOrganId) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        SrvOrganVo srvOrganVo = srvOrganService.getSrvOrganDetail(srvOrganId);
        return Result.success(srvOrganVo);
    }

    /**
     * 删除护理机构
     *
     * @param srvOrganId 护理机构id
     * @return 返回执行结果
     */
    @DeleteMapping("/srvOrgan")
    public Result<SrvOrganVo> deleteSrvOrgan(Long srvOrganId) {
        if (null == srvOrganId) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        srvOrganService.deleteSrvOrgan(srvOrganId);
        return Result.success();
    }

}
